@@ -21,9 +21,26 @@ use Params::Util qw{ _IDENTIFIER _POSINT _INSTANCE _DRIVER };
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.00';
+	$VERSION = '1.01';
 }
 
+use Object::Tiny::XS qw{
+	name
+	driver
+	file
+	image
+	height
+	width
+	string
+};
+
+
+
+
+
+######################################################################
+# Constructor and Accessors
+
 sub new {
 	my $class = shift;
 	my $self  = bless { @_ }, $class;
@@ -61,34 +78,6 @@ sub new {
 	return $self;
 }
 
-sub name {
-	$_[0]->{name};
-}
-
-sub driver {
-	$_[0]->{driver};
-}
-
-sub file {
-	$_[0]->{file};
-}
-
-sub image {
-	$_[0]->{image};
-}
-
-sub height {
-	$_[0]->{height};
-}
-
-sub width {
-	$_[0]->{width};
-}
-
-sub string {
-	$_[0]->{string};
-}
-
 
 
 
@@ -160,7 +149,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2007 - 2008 Adam Kennedy.
+Copyright 2007 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
